==> aroundme_0_3_3.zip: aroundme_0_3_3/www/language/1/index.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


require_once($languagePath . 'common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//SECTIONS
$lang['section_intro'] = 						"introducing nodeX";
$lang['section_login'] = 						"login";
$lang['section_password'] = 					"forgotten password?";


//LINK TITLES
$lang['title_map'] = 							"we rock!";


//TEXTS
$lang['txt_intro'] = 							"Your welcome message<br />";
$lang['txt_email'] = 							"your email address";
$lang['txt_password'] = 						"your password";
$lang['txt_new_password'] = 					"If you have forgotten your password you can <a href =\"new_password.php\">get a new password here</a>.";

?>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/language/1/index.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


require_once($languagePath . 'common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//SECTIONS
$lang['section_intro'] = 						"introducing nodeX";
$lang['section_login'] = 						"login";
$lang['section_password'] = 					"forgotten password?";
$lang['section_blogs'] = 						"blogs";
$lang['section_polls'] = 						"polls";
$lang['section_library_items'] = 				"library items";


//LINK TITLES
$lang['title_map'] = 							"we rock!";


//TEXTS
$lang['txt_intro'] = 							"Your welcome message<br />";
$lang['txt_email'] = 							"your email address";
$lang['txt_password'] = 						"your password";
$lang['txt_new_password'] = 					"If you have forgotten your password you can <a href =\"new_password.php\">get a new password here</a>.";
$lang['txt_votes'] = 							"votes";
?>
